Documentation
¶
Index ¶
Constants ¶
const ( HeaderFeedback = "CICD-Feedback" HeaderAuthorization = "CICD-Authorization" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ErrorResponse ¶
type ErrorResponse struct {
Error ErrorType `json:"error"`
ErrorDescription string `json:"errorDescription,omitempty"`
}
ErrorResponse represents the structure of an error response
type ErrorType ¶
type ErrorType string
ErrorType represents the possible error types
const ( // ErrorInternal: CI/CD engine encountered an unexpected internal error ErrorInternal ErrorType = "internal" // ErrorConfig: Error in the pipeline configuration or workflow definition ErrorConfig ErrorType = "config" // ErrorExternal: Error in an external service that the CI/CD engine depends on ErrorExternal ErrorType = "external" // ErrorPermission: Insufficient permissions to perform the requested action ErrorPermission ErrorType = "permission" // ErrorValidation: Input validation errors ErrorValidation ErrorType = "validation" // ErrorOther: All other unspecified error ErrorOther ErrorType = "other" )
type PipelineResponse ¶
type PipelineResponse struct {
PipelineID string `json:"pipelineId"`
Title string `json:"title"`
Status Status `json:"status"`
RequiresManualAction bool `json:"requiresManualAction"`
Workflows []Workflow `json:"workflows"`
ExternalURI string `json:"externalURI,omitempty"`
}
PipelineResponse represents the structure of a successful pipeline response
type WellKnownResponse ¶
Click to show internal directories.
Click to hide internal directories.